@@ -29,16 +29,18 @@
  **/
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include <gio/gio.h>
 
 #include "xfce-consolekit.h"
+#include "libxfce4util-visibility.h"
 
 
 
-static void     xfce_consolekit_finalize     (GObject         *object);
+static void
+xfce_consolekit_finalize (GObject *object);
 
 
 
@@ -112,13 +114,32 @@ name_vanished (GDBusConnection *connection,
 static void
 xfce_consolekit_init (XfceConsolekit *consolekit)
 {
-  consolekit->watch_id = g_bus_watch_name (G_BUS_TYPE_SYSTEM,
-                                           "org.freedesktop.ConsoleKit",
-                                           G_BUS_NAME_WATCHER_FLAGS_AUTO_START,
-                                           name_appeared,
-                                           name_vanished,
-                                           consolekit,
-                                           NULL);
+  GError *error = NULL;
+
+  /* try to create a proxy synchronously with default flags, so the returned
+   * object is immediately usable */
+  consolekit->proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SYSTEM,
+                                                     G_DBUS_PROXY_FLAGS_NONE,
+                                                     NULL,
+                                                     "org.freedesktop.ConsoleKit",
+                                                     "/org/freedesktop/ConsoleKit/Manager",
+                                                     "org.freedesktop.ConsoleKit.Manager",
+                                                     NULL,
+                                                     &error);
+  if (error != NULL)
+    {
+      g_warning ("Failed to get a ConsoleKit proxy: %s", error->message);
+      g_error_free (error);
+
+      /* watch the name if it failed, maybe we'll have better luck later */
+      consolekit->watch_id = g_bus_watch_name (G_BUS_TYPE_SYSTEM,
+                                               "org.freedesktop.ConsoleKit",
+                                               G_BUS_NAME_WATCHER_FLAGS_AUTO_START,
+                                               name_appeared,
+                                               name_vanished,
+                                               consolekit,
+                                               NULL);
+    }
 }
 
 
@@ -128,7 +149,8 @@ xfce_consolekit_finalize (GObject *object)
 {
   XfceConsolekit *consolekit = XFCE_CONSOLEKIT (object);
 
-  g_bus_unwatch_name (consolekit->watch_id);
+  if (consolekit->watch_id != 0)
+    g_bus_unwatch_name (consolekit->watch_id);
   g_clear_object (&consolekit->proxy);
 
   G_OBJECT_CLASS (xfce_consolekit_parent_class)->finalize (object);
@@ -155,6 +177,7 @@ xfce_consolekit_can_method_old (XfceConsolekit *consolekit,
   if (consolekit->proxy == NULL)
     {
       g_debug ("No ConsoleKit proxy");
+      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED, "No ConsoleKit proxy available");
       return FALSE;
     }
 
@@ -204,6 +227,7 @@ xfce_consolekit_can_method (XfceConsolekit *consolekit,
   if (consolekit->proxy == NULL)
     {
       g_debug ("No ConsoleKit proxy");
+      g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED, "No ConsoleKit proxy available");
       return FALSE;
     }
 
@@ -641,3 +665,6 @@ xfce_consolekit_can_hybrid_sleep (XfceConsolekit *consolekit,
 
   return xfce_consolekit_can_method (consolekit, "CanHybridSleep", can_hybrid_sleep, auth_hybrid_sleep, error);
 }
+
+#define __XFCE_CONSOLEKIT_C__
+#include "libxfce4util-visibility.c"
